@@ -13,6 +13,7 @@ class GeoLocation : public QObject
 {
     Q_PROPERTY(double latitude READ latitude)
     Q_PROPERTY(double longitude READ longitude)
+    Q_PROPERTY(double horizontalAccuracy READ horizontalAccuracy)
     Q_OBJECT
 
 public:
@@ -22,10 +23,10 @@ public:
 public:
     void setUpdatesPerHour(int updates);
     QString toString();
-    Location getLastLocation() { return m_lastLocation; }
-    double latitude() { return m_lastLocation.latitude(); }
-    double longitude() { return m_lastLocation.longitude(); }
-    bool isUpdating() { return m_isUpdating; }
+    double latitude();
+    double longitude();
+    qreal horizontalAccuracy();
+    bool isUpdating();
 
 signals:
     void updated();
@@ -37,7 +38,8 @@ private:
     QGeoPositionInfoSource *m_pSource;
     QGeoSatelliteInfoSource *m_pSatellite;
     bool m_isUpdating;
-    Location m_lastLocation;
+    QGeoPositionInfo m_lastLocation;
+    // Location m_lastLocation;
 };
 
 #endif // GEOLOCATION_H
