@@ -65,7 +65,7 @@ MainWindow::MainWindow(QWidget *parent) :
     m_startAddress.setCoordinates( 35.8185 ,  -78.8641);
 
     init();
-    createMenu();
+    // createMenu();
 }
 
 MainWindow::~MainWindow() {
@@ -147,17 +147,13 @@ void MainWindow::init() {
 
     pPage->settings()->setAttribute(QWebSettings::OfflineStorageDatabaseEnabled, true);
     pPage->settings()->setAttribute(QWebSettings::OfflineWebApplicationCacheEnabled, true);
-
     connect(pFrame, SIGNAL(javaScriptWindowObjectCleared()), SLOT(javaScriptWindowObjectCleared()));
 
-
 #ifdef Q_WS_MAEMO_5
     connect(&m_geoLocation, SIGNAL(updated()), SLOT(onPositionUpdated()));
     grabZoomKeys(true);
 #endif
 
-    ui->webView->setUrl( QUrl::fromUserInput("http://www.crochik.com/gps1.html") );
-
     MouseSuppressor *pSupperssor = new MouseSuppressor(ui->webView);
     connect(pSupperssor, SIGNAL(click(QMouseEvent*)), SLOT(onClick(QMouseEvent*)));
 
@@ -171,17 +167,43 @@ void MainWindow::init() {
     connect(m_pToolButtons[2], SIGNAL(clicked()), SLOT(onEast()));
     connect(m_pToolButtons[3], SIGNAL(clicked()), SLOT(onSouth()));
     for ( int c=0; c<4; c++ ) m_pToolButtons[c]->setVisible(false);
+
+    connect(ui->webView, SIGNAL(loadFinished(bool)), SLOT(onLoadFinished(bool)));
+    load();
+}
+
+void MainWindow::load() {
+    ui->webView->setUrl( QUrl::fromUserInput("http://www.crochik.com/gps2.html") );
+}
+
+void MainWindow::onLoadFinished(bool isSuccess) {
+    if ( !isSuccess ) {
+        if ( QMessageBox::question(
+            this, "Failed to Load Map", "Would you like to try again?",
+            QMessageBox::Yes, QMessageBox::No)
+            == QMessageBox::Yes
+        ){
+            load();
+            return;
+        }
+        // abort
+        close();
+        return;
+    }
+
+    // ready!
+    qDebug() << "loaded html page";
+    ui->webView->disconnect(this, SLOT(onLoadFinished(bool)));
+    createMenu();
 }
 
 void MainWindow::createMenu() {
-    // views
-    m_pViewGroup = new QActionGroup(this);
-    connect(m_pViewGroup, SIGNAL(triggered(QAction*)), this, SLOT(onViewChanged(QAction*)));
-    m_pViewGroup->setExclusive(true);
-
     QSettings settings;
 
+    // views
     int viewMode = settings.value("Mode", 1).toInt();
+    m_pViewGroup = new QActionGroup(this);
+    m_pViewGroup->setExclusive(true);
 
     QAction *pAction;
     pAction = new QAction("Hybrid", m_pViewGroup); pAction->setCheckable(true); pAction->setChecked(viewMode==0);
@@ -189,6 +211,8 @@ void MainWindow::createMenu() {
     pAction = new QAction("Satellite", m_pViewGroup); pAction->setCheckable(true); pAction->setChecked(viewMode==2);
     pAction = new QAction("Terrain", m_pViewGroup); pAction->setCheckable(true); pAction->setChecked(viewMode==3);
     menuBar()->addActions(m_pViewGroup->actions());
+    connect(m_pViewGroup, SIGNAL(triggered(QAction*)), this, SLOT(onViewChanged(QAction*)));
+    setView(viewMode);
 
     // menuBar()->addAction("Reload", this, SLOT(reload()));
     // menuBar()->addAction("Find Address", this, SLOT(find()));
@@ -213,6 +237,10 @@ void MainWindow::createMenu() {
     m_pCyclingLayer->setCheckable(true);
     m_pCyclingLayer->setChecked(bicycle);
 
+    m_pAccuracyAction = menuBar()->addAction("Show Accuracy", this, SLOT(onShowAccuracy()));
+    m_pAccuracyAction->setCheckable(true);
+    m_pAccuracyAction->setChecked(false);
+
     if ( traffic ) onTrafficLayer();
     if ( bicycle ) onBicyclingLayer();
 
@@ -240,6 +268,10 @@ void MainWindow::createMenu() {
 #endif
 }
 
+void MainWindow::onShowAccuracy() {
+    if ( !m_pAccuracyAction->isChecked() ) runJavascript("radius=null;");
+}
+
 void MainWindow::onTrafficLayer() {
     QSettings settings;
     settings.setValue("TrafficLayer", m_pTrafficLayer->isChecked());
@@ -335,9 +367,10 @@ void MainWindow::onHideButtons() {
 }
 
 void MainWindow::onViewChanged(QAction* pAction) {
-    // google.maps.MapTypeId. // HYBRID ROADMAP SATELLITE TERRAIN
+    setView(m_pViewGroup->actions().indexOf(pAction));
+}
 
-    int index = m_pViewGroup->actions().indexOf(pAction);
+void MainWindow::setView(int index) {
     QString value;
     switch ( index ) {
         case 0: value = "HYBRID"; break;
@@ -350,7 +383,6 @@ void MainWindow::onViewChanged(QAction* pAction) {
 
     QSettings settings;
     settings.setValue("Mode", index);
-
     runJavascript("map.setMapTypeId(google.maps.MapTypeId." + value + ");");
 }
 
@@ -616,14 +648,14 @@ void MainWindow::onPositionUpdated() {
     Location last = m_startAddress;
 
     // reset start
-    m_startAddress = m_geoLocation.getLastLocation();
+    m_startAddress.setCoordinates( m_geoLocation.latitude(), m_geoLocation.longitude());
     m_startAddress.setDescription(QString("%1 %2").arg(QString::number(m_startAddress.latitude()), QString::number(m_startAddress.longitude())));
 
     // m_startAddress.setCoordinates(last.latitude()+.001, last.longitude());
 
     if ( m_isAutoCenter && m_isAutoRotate ) {
-        double dx = m_geoLocation.getLastLocation().longitude() - last.longitude();
-        double dy = m_geoLocation.getLastLocation().latitude() - last.latitude();
+        double dx = m_geoLocation.longitude() - last.longitude();
+        double dy = m_geoLocation.latitude() - last.latitude();
 
         int angle = 0;
         if ( (dx>0 && dy>0 && dx>dy) || (dx<0 && dy<0 && dx<dy) || (dx>0 && dy<0 && dx>-dy) || (dx<0 && dy>0 && dx<-dy) ) {
@@ -647,10 +679,11 @@ void MainWindow::onPositionUpdated() {
     }
 
     runJavascript(
-        QString("updateCenter(%1, %2, %3);").arg(
+        QString("updateCenter(%1, %2, %3, %4);").arg(
             m_isAutoCenter?"true":"false",
-            QString::number(m_startAddress.latitude()),
-            QString::number(m_startAddress.longitude())
+            QString::number(m_geoLocation.latitude()),
+            QString::number(m_geoLocation.longitude()),
+            m_pAccuracyAction->isChecked() ? QString::number(m_geoLocation.horizontalAccuracy()) : "0"
         )
     );
 
