@@ -58,19 +58,19 @@ protected:
     virtual void keyPressEvent(QKeyEvent *event);
     virtual void resizeEvent(QResizeEvent *pEvent);
 
-public: // MainAppWindow
-    virtual void init();
-
-protected: // MainAppWindow
-    virtual void createMenu();
+public:
+    void init();
 
 private:
+    void createMenu();
+    void load();
     void runJavascript(QString script);
     void incrementTimer();
     void showCurrentDirections();
     void resetDirections();
     void showProgressIndicator(bool show);
     void getDirectionsOnMap();
+    void setView(int index);
 
 public slots:
     void javaScriptWindowObjectCleared();
@@ -92,7 +92,9 @@ public slots:
     void onSourceUpdates(int);
     void onAutoRotate();
     void onTrafficLayer();
+    void onShowAccuracy();
     void onBicyclingLayer();
+    void onLoadFinished(bool);
 
 private:
     Ui::MainWindow *ui;
@@ -101,6 +103,7 @@ private:
     QAction                 *m_pAutoRotateAction;
     QAction                 *m_pTrafficLayer;
     QAction                 *m_pCyclingLayer;
+    QAction                 *m_pAccuracyAction;
 
     bool                    m_isAutoCenter;
     bool                    m_isAutoRotate;
